##  Endpoints
SAP Signavio provides endpoints to obtain SAP Signavio Processes as well as Glossary Items as structured data.
The integration currently provides access to three SAP Signavio endpoints. The path within the structured data can be specified in the Information Source field of the configuration with a starting keyword that refers to each endpoint.
  * For Processes: /p/editordata?id=(id) keyword: editordata
  * For Processes: /p/model/(id)/info keyword: model
  * For Glossary Items: /p/glossary/(id)/info keyword: glossary


In the following sections we will describe how to explore the data that can be obtained from those endpoints using the Chrome Browser.
